
package walpo.modelo;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 *
 * @author Antonio López
 */
public class LineaFinal {

    public static final String CARACTER_COMA = ",";
    public static final String CARACTER_ESPACIO = " ";

    public static final String ACCEDIDO = "T";
    public static final String NO_ACCEDIDO = "F";

    private String direccionIP;
    private String idSesion;

    //Es necesario utilizar un LinkedHashMap para mantener la ordenación de claves.
    //Los HashMap normales no aseguran mantener el orden de las claves durante toda la ejecución.
    private LinkedHashMap<String, String> listaRecursos;


    public LineaFinal(String direccionIP, String idSesion, ArrayList<String> listaRecursosSolicitados, String recursoSolicitado) {
        this.direccionIP = direccionIP;
        this.idSesion = idSesion;
        this.inicializarListaRecursos(listaRecursosSolicitados, recursoSolicitado);
    }

    /**
     * @return the direccionIP
     */
    public String getDireccionIP() {
        return direccionIP;
    }

    /**
     * @param direccionIP the direccionIP to set
     */
    public void setDireccionIP(String direccionIP) {
        this.direccionIP = direccionIP;
    }

    /**
     * @return the idSesion
     */
    public String getIdSesion() {
        return idSesion;
    }

    /**
     * @param idSesion the idSesion to set
     */
    public void setIdSesion(String idSesion) {
        this.idSesion = idSesion;
    }

    /**
     * @return the listaRecursos
     */
    public LinkedHashMap<String, String> getListaRecursos() {
        return listaRecursos;
    }

    /**
     * @param listaRecursos the listaRecursos to set
     */
    public void setListaRecursos(LinkedHashMap<String, String> listaRecursos) {
        this.listaRecursos = listaRecursos;
    }

    /**
     * Recorrer la lista de recursos solicitados que figuraban en el archivo de log,
     * cargarlos en la lista de recursos de la línea final tratada y asignar
     * valores 'T' o 'F' según el recurso haya sido accedido por la IP o no
     * @param listaRecursosSolicitados
     * @param recursoSolicitado
     */
    public void inicializarListaRecursos(ArrayList<String> listaRecursosSolicitados, String recursoSolicitado) {

        //Instanciar la lista en caso de no haberlo hecho previamente
        if (this.listaRecursos == null) { this.listaRecursos = new LinkedHashMap<String, String>(); }

        //Recorrer la lista de recursos solicitados e inicializar la lista de recursos
        //de la línea que se está tratando
        for (String recurso : listaRecursosSolicitados) {

            if (recurso.equals(recursoSolicitado)) {
                this.listaRecursos.put(recurso, ACCEDIDO);
            } else {
                //En caso de tener que asinar valor 'F', antes es necesario valorar
                //si el recurso ya existía en la lista para no sobrescribirlo
                if (!this.listaRecursos.containsKey(recurso)) {
                    this.listaRecursos.put(recurso, NO_ACCEDIDO);
                }
            }
        }
    }

    /**
     * Definir una línea con el formato y separador indicados.
     * @param separador
     * @return
     */
    public String getLineaFinal(String separador) {

        String linea = this.getDireccionIP() + separador;

        Iterator it = this.listaRecursos.entrySet().iterator();
        while (it.hasNext()) {

            Map.Entry e = (Map.Entry) it.next();
            linea += e.getValue();
            if (it.hasNext()) { linea +=  separador; }
        }

        return linea;
    }
}
